@@ -1,11 +1,10 @@
-from typing import Tuple, Dict, List
-
+from typing import Tuple, Dict, List, Any
 import numpy as np
 import logging
 from pyobs.object import get_object
 
 from pyobs.images.processors.detection import SourceDetection
-from .base import FocusSeries
+from pyobs.utils.focusseries.base import FocusSeries
 from pyobs.utils.curvefit import fit_hyperbola
 from pyobs.images import Image
 
@@ -15,9 +14,10 @@ log = logging.getLogger(__name__)
 
 class PhotometryFocusSeries(FocusSeries):
     """Focus series based on source detection."""
-    __module__ = 'pyobs.utils.focusseries'
 
-    def __init__(self, source_detection: SourceDetection, radius_column: str = 'radius', *args, **kwargs):
+    __module__ = "pyobs.utils.focusseries"
+
+    def __init__(self, source_detection: SourceDetection, radius_column: str = "radius", **kwargs: Any):
         """Initialize a new projection focus series.
 
         Args:
@@ -29,11 +29,11 @@ class PhotometryFocusSeries(FocusSeries):
         self._radius_col = radius_column
         self._data: List[Dict[str, float]] = []
 
-    def reset(self):
+    def reset(self) -> None:
         """Reset focus series."""
         self._data = []
 
-    def analyse_image(self, image: Image):
+    def analyse_image(self, image: Image) -> None:
         """Analyse given image.
 
         Args:
@@ -41,20 +41,25 @@ class PhotometryFocusSeries(FocusSeries):
         """
 
         # do photometry
-        sources = self._source_detection(image)
-        sources = sources[sources['ellipticity'] < 0.1]
-        sources = sources[sources['peak'] > 1000]
-        sources = sources[sources['radius'] > 0]
+        self._source_detection(image)
+
+        # filter
+        sources = image.catalog
+        if sources is None:
+            return
+        sources = sources[sources["ellipticity"] < 0.1]
+        sources = sources[sources["peak"] > 1000]
+        sources = sources[sources["radius"] > 0]
 
         # calculate median radius
-        radius = np.median(sources['radius'])
-        radius_err = np.std(sources['radius'])
+        radius = np.median(sources["radius"])
+        radius_err = np.std(sources["radius"])
 
         # log it
-        log.info('Found median radius of %.1f+-%.1f.', radius, radius_err)
+        log.info("Found median radius of %.1f+-%.1f.", radius, radius_err)
 
         # add to list
-        self._data.append({'focus': float(image.header['TEL-FOCU']), 'r': radius, 'rerr': radius_err})
+        self._data.append({"focus": float(image.header["TEL-FOCU"]), "r": radius, "rerr": radius_err})
 
     def fit_focus(self) -> Tuple[float, float]:
         """Fit focus from analysed images
@@ -64,15 +69,15 @@ class PhotometryFocusSeries(FocusSeries):
         """
 
         # get data
-        focus = [d['focus'] for d in self._data]
-        r = [d['r'] for d in self._data]
-        rerr = [d['rerr'] for d in self._data]
+        focus = [d["focus"] for d in self._data]
+        r = [d["r"] for d in self._data]
+        rerr = [d["rerr"] for d in self._data]
 
         # fit focus
         try:
             foc, err = fit_hyperbola(focus, r, rerr)
         except (RuntimeError, RuntimeWarning):
-            raise ValueError('Could not find best focus.')
+            raise ValueError("Could not find best focus.")
 
         # get min and max foci
         min_focus = np.min(focus)
@@ -84,4 +89,4 @@ class PhotometryFocusSeries(FocusSeries):
         return float(foc), float(err)
 
 
-__all__ = ['PhotometryFocusSeries']
+__all__ = ["PhotometryFocusSeries"]
